@@ -5,7 +5,7 @@
 
 //! Theme configuration
 
-use crate::{ColorsLinear, ColorsSrgb, ThemeConfig};
+use crate::{ColorsSrgb, ThemeConfig};
 use kas::draw::TextClass;
 use kas::text::fonts::{fonts, AddMode, FontSelector};
 use kas::TkAction;
@@ -223,6 +223,7 @@ impl ThemeConfig for Config {
 #[derive(Clone, Debug, PartialEq)]
 #[cfg_attr(feature = "config", derive(serde::Serialize, serde::Deserialize))]
 pub struct FontAliases {
+    #[cfg_attr(feature = "config", serde(default = "defaults::add_mode"))]
     mode: AddMode,
     list: Vec<String>,
 }
@@ -230,15 +231,19 @@ pub struct FontAliases {
 mod defaults {
     use super::*;
 
+    pub fn add_mode() -> AddMode {
+        AddMode::Prepend
+    }
+
     pub fn font_size() -> f32 {
         10.0
     }
 
     pub fn color_schemes() -> BTreeMap<String, ColorsSrgb> {
         let mut schemes = BTreeMap::new();
-        schemes.insert("".to_string(), ColorsLinear::white_blue().into());
-        schemes.insert("light".to_string(), ColorsLinear::light().into());
-        schemes.insert("dark".to_string(), ColorsLinear::dark().into());
+        schemes.insert("light".to_string(), ColorsSrgb::light());
+        schemes.insert("dark".to_string(), ColorsSrgb::dark());
+        schemes.insert("blue".to_string(), ColorsSrgb::blue());
         schemes
     }
 
