@@ -26,18 +26,26 @@ pub struct Parameters {
     pub outer_margin: f32,
     /// Margin inside a frame before contents
     pub inner_margin: f32,
+    /// Margin around frames and seperators
+    pub frame_margin: f32,
     /// Margin between text elements
     pub text_margin: f32,
     /// Frame size
     pub frame_size: f32,
     /// Button frame size (non-flat outer region)
     pub button_frame: f32,
+    /// Checkbox inner size in Points
+    pub checkbox_inner: f32,
     /// Scrollbar minimum handle size
     pub scrollbar_size: Vec2,
     /// Slider minimum handle size
     pub slider_size: Vec2,
     /// Progress bar size (horizontal)
     pub progress_bar: Vec2,
+    /// Shadow size (average)
+    pub shadow_size: Vec2,
+    /// Proportional offset of shadow (range: -1..=1)
+    pub shadow_rel_offset: Vec2,
 }
 
 /// Dimensions available within [`Window`]
@@ -51,6 +59,7 @@ pub struct Dimensions {
     pub min_line_length: i32,
     pub outer_margin: u16,
     pub inner_margin: u16,
+    pub frame_margin: u16,
     pub text_margin: u16,
     pub frame: i32,
     pub button_frame: i32,
@@ -58,10 +67,12 @@ pub struct Dimensions {
     pub scrollbar: Size,
     pub slider: Size,
     pub progress_bar: Size,
+    pub shadow_a: Vec2,
+    pub shadow_b: Vec2,
 }
 
 impl Dimensions {
-    pub fn new(params: Parameters, pt_size: f32, scale_factor: f32) -> Self {
+    pub fn new(params: &Parameters, pt_size: f32, scale_factor: f32) -> Self {
         let font_id = Default::default();
         let dpp = scale_factor * (96.0 / 72.0);
         let dpem = dpp * pt_size;
@@ -73,8 +84,13 @@ impl Dimensions {
 
         let outer_margin = (params.outer_margin * scale_factor).cast_nearest();
         let inner_margin = (params.inner_margin * scale_factor).cast_nearest();
+        let frame_margin = (params.frame_margin * scale_factor).cast_nearest();
         let text_margin = (params.text_margin * scale_factor).cast_nearest();
         let frame = (params.frame_size * scale_factor).cast_nearest();
+
+        let shadow_size = params.shadow_size * scale_factor;
+        let shadow_offset = shadow_size * params.shadow_rel_offset;
+
         Dimensions {
             scale_factor,
             dpp,
@@ -84,13 +100,17 @@ impl Dimensions {
             min_line_length: (8.0 * dpem).cast_nearest(),
             outer_margin,
             inner_margin,
+            frame_margin,
             text_margin,
             frame,
             button_frame: (params.button_frame * scale_factor).cast_nearest(),
-            checkbox: i32::conv_nearest(9.0 * dpp) + 2 * (i32::from(inner_margin) + frame),
+            checkbox: i32::conv_nearest(params.checkbox_inner * dpp)
+                + 2 * (i32::from(inner_margin) + frame),
             scrollbar: Size::from(params.scrollbar_size * scale_factor),
             slider: Size::from(params.slider_size * scale_factor),
             progress_bar: Size::from(params.progress_bar * scale_factor),
+            shadow_a: shadow_offset - shadow_size,
+            shadow_b: shadow_offset + shadow_size,
         }
     }
 }
@@ -103,7 +123,7 @@ pub struct Window {
 
 impl Window {
     pub fn new(
-        dims: Parameters,
+        dims: &Parameters,
         pt_size: f32,
         scale_factor: f32,
         fonts: Rc<LinearMap<TextClass, FontId>>,
@@ -114,7 +134,7 @@ impl Window {
         }
     }
 
-    pub fn update(&mut self, dims: Parameters, pt_size: f32, scale_factor: f32) {
+    pub fn update(&mut self, dims: &Parameters, pt_size: f32, scale_factor: f32) {
         self.dims = Dimensions::new(dims, pt_size, scale_factor);
     }
 }
@@ -143,7 +163,7 @@ impl SizeHandle for Window {
     }
 
     fn frame(&self, _vert: bool) -> FrameRules {
-        FrameRules::new_sym(self.dims.frame, 0, 0)
+        FrameRules::new_sym(self.dims.frame, 0, self.dims.frame_margin)
     }
     fn menu_frame(&self, vert: bool) -> FrameRules {
         let mut size = self.dims.frame;
@@ -168,6 +188,10 @@ impl SizeHandle for Window {
         Margins::splat(self.dims.outer_margin)
     }
 
+    fn frame_margins(&self) -> Margins {
+        Margins::splat(self.dims.frame_margin)
+    }
+
     fn text_margins(&self) -> Margins {
         Margins::splat(self.dims.text_margin)
     }
