@@ -58,17 +58,21 @@ impl ShadedTheme {
 const DIMS: dim::Parameters = dim::Parameters {
     outer_margin: 6.0,
     inner_margin: 1.2,
+    frame_margin: 1.2,
     text_margin: 2.0,
     frame_size: 5.0,
     button_frame: 5.0,
+    checkbox_inner: 9.0,
     scrollbar_size: Vec2::splat(8.0),
     slider_size: Vec2(12.0, 25.0),
     progress_bar: Vec2::splat(12.0),
+    shadow_size: Vec2::splat(6.0),
+    shadow_rel_offset: Vec2::ZERO,
 };
 
 pub struct DrawHandle<'a, DS: DrawSharedImpl> {
     draw: DrawIface<'a, DS>,
-    window: &'a mut dim::Window,
+    w: &'a mut dim::Window,
     cols: &'a ColorsLinear,
 }
 
@@ -98,19 +102,15 @@ where
 
     fn new_window(&self, dpi_factor: f32) -> Self::Window {
         let fonts = self.flat.fonts.as_ref().unwrap().clone();
-        dim::Window::new(DIMS, self.flat.config.font_size(), dpi_factor, fonts)
+        dim::Window::new(&DIMS, self.flat.config.font_size(), dpi_factor, fonts)
     }
 
-    fn update_window(&self, window: &mut Self::Window, dpi_factor: f32) {
-        window.update(DIMS, self.flat.config.font_size(), dpi_factor);
+    fn update_window(&self, w: &mut Self::Window, dpi_factor: f32) {
+        w.update(&DIMS, self.flat.config.font_size(), dpi_factor);
     }
 
     #[cfg(not(feature = "gat"))]
-    unsafe fn draw_handle(
-        &self,
-        draw: DrawIface<DS>,
-        window: &mut Self::Window,
-    ) -> Self::DrawHandle {
+    unsafe fn draw_handle(&self, draw: DrawIface<DS>, w: &mut Self::Window) -> Self::DrawHandle {
         unsafe fn extend_lifetime<'b, T: ?Sized>(r: &'b T) -> &'static T {
             std::mem::transmute::<&'b T, &'static T>(r)
         }
@@ -123,7 +123,7 @@ where
                 shared: extend_lifetime_mut(draw.shared),
                 pass: draw.pass,
             },
-            window: extend_lifetime_mut(window),
+            w: extend_lifetime_mut(w),
             cols: extend_lifetime(&self.flat.cols),
         }
     }
@@ -131,11 +131,11 @@ where
     fn draw_handle<'a>(
         &'a self,
         draw: DrawIface<'a, DS>,
-        window: &'a mut Self::Window,
+        w: &'a mut Self::Window,
     ) -> Self::DrawHandle<'a> {
         DrawHandle {
             draw,
-            window,
+            w,
             cols: &self.flat.cols,
         }
     }
@@ -171,7 +171,7 @@ where
     {
         super::flat_theme::DrawHandle {
             draw: self.draw.reborrow(),
-            window: self.window,
+            w: self.w,
             cols: self.cols,
         }
     }
@@ -184,7 +184,7 @@ where
     /// - `nav_col`: colour of navigation highlight, if visible
     fn draw_edit_box(&mut self, outer: Rect, bg_col: Rgba, nav_col: Option<Rgba>) -> Quad {
         let mut outer = Quad::from(outer);
-        let mut inner = outer.shrink(self.window.dims.frame as f32);
+        let mut inner = outer.shrink(self.w.dims.frame as f32);
 
         let col = self.cols.background;
         self.draw
@@ -192,7 +192,7 @@ where
 
         if let Some(col) = nav_col {
             outer = inner;
-            inner = outer.shrink(self.window.dims.inner_margin as f32);
+            inner = outer.shrink(self.w.dims.inner_margin as f32);
             self.draw.frame(outer, inner, col);
         }
 
@@ -205,7 +205,7 @@ where
         let outer = Quad::from(rect);
         let thickness = outer.size().min_comp() / 2.0;
         let inner = outer.shrink(thickness);
-        let col = self.cols.scrollbar_state(state);
+        let col = self.cols.accent_soft_state(state);
         self.draw.shaded_round_frame(outer, inner, (0.0, 0.6), col);
 
         if let Some(col) = self.cols.nav_region(state) {
@@ -220,10 +220,10 @@ where
     DS::Draw: DrawRoundedImpl + DrawShadedImpl,
 {
     fn size_handle(&mut self) -> &mut dyn SizeHandle {
-        self.window
+        self.w
     }
 
-    fn draw_device<'b>(&'b mut self) -> &mut dyn Draw {
+    fn draw_device(&mut self) -> &mut dyn Draw {
         &mut self.draw
     }
 
@@ -234,22 +234,28 @@ where
         class: PassType,
         f: &mut dyn FnMut(&mut dyn draw::DrawHandle),
     ) {
+        let mut shadow = Default::default();
         let mut outer_rect = inner_rect;
         if class == PassType::Overlay {
-            outer_rect = inner_rect.expand(self.window.dims.frame);
+            shadow = Quad::from(inner_rect);
+            shadow.a += self.w.dims.shadow_a;
+            shadow.b += self.w.dims.shadow_b;
+            let a = shadow.a.floor();
+            let b = shadow.b.ceil();
+            outer_rect = Rect::new(a.into(), (b - a).into());
         }
         let mut draw = self.draw.new_pass(outer_rect, offset, class);
 
         if class == PassType::Overlay {
-            let outer = Quad::from(outer_rect + offset);
+            shadow += offset.into();
             let inner = Quad::from(inner_rect + offset);
-            let norm = (0.0, 0.0);
-            draw.shaded_square_frame(outer, inner, norm, Rgba::TRANSPARENT, Rgba::BLACK);
+            draw.rounded_frame_2col(shadow, inner, Rgba::BLACK, Rgba::TRANSPARENT);
+
             draw.rect(inner, self.cols.background);
         }
 
         let mut handle = DrawHandle {
-            window: self.window,
+            w: self.w,
             draw,
             cols: self.cols,
         };
@@ -262,7 +268,7 @@ where
 
     fn outer_frame(&mut self, rect: Rect) {
         let outer = Quad::from(rect);
-        let inner = outer.shrink(self.window.dims.frame as f32);
+        let inner = outer.shrink(self.w.dims.frame as f32);
         let norm = (0.7, -0.7);
         let col = self.cols.background;
         self.draw.shaded_round_frame(outer, inner, norm, col);
@@ -284,16 +290,29 @@ where
         self.as_flat().selection_box(rect);
     }
 
-    fn text(&mut self, pos: Coord, text: &TextDisplay, class: TextClass) {
-        self.as_flat().text(pos, text, class);
+    fn text(&mut self, pos: Coord, text: &TextDisplay, class: TextClass, state: InputState) {
+        self.as_flat().text(pos, text, class, state);
     }
 
-    fn text_effects(&mut self, pos: Coord, text: &dyn TextApi, class: TextClass) {
-        self.as_flat().text_effects(pos, text, class);
+    fn text_effects(
+        &mut self,
+        pos: Coord,
+        text: &dyn TextApi,
+        class: TextClass,
+        state: InputState,
+    ) {
+        self.as_flat().text_effects(pos, text, class, state);
     }
 
-    fn text_accel(&mut self, pos: Coord, text: &Text<AccelString>, state: bool, class: TextClass) {
-        self.as_flat().text_accel(pos, text, state, class);
+    fn text_accel(
+        &mut self,
+        pos: Coord,
+        text: &Text<AccelString>,
+        accel: bool,
+        class: TextClass,
+        state: InputState,
+    ) {
+        self.as_flat().text_accel(pos, text, accel, class, state);
     }
 
     fn text_selected_range(
@@ -302,8 +321,10 @@ where
         text: &TextDisplay,
         range: Range<usize>,
         class: TextClass,
+        state: InputState,
     ) {
-        self.as_flat().text_selected_range(pos, text, range, class);
+        self.as_flat()
+            .text_selected_range(pos, text, range, class, state);
     }
 
     fn edit_marker(&mut self, pos: Coord, text: &TextDisplay, class: TextClass, byte: usize) {
@@ -316,26 +337,26 @@ where
 
     fn button(&mut self, rect: Rect, col: Option<color::Rgb>, state: InputState) {
         let outer = Quad::from(rect);
-        let inner = outer.shrink(self.window.dims.button_frame as f32);
-        let col = col.map(|c| c.into()).unwrap_or(self.cols.button);
+        let inner = outer.shrink(self.w.dims.button_frame as f32);
+        let col = col.map(|c| c.into()).unwrap_or(self.cols.accent_soft);
         let col = ColorsLinear::adjust_for_state(col, state);
 
         self.draw.shaded_round_frame(outer, inner, (0.0, 0.6), col);
         self.draw.rect(inner, col);
 
         if let Some(col) = self.cols.nav_region(state) {
-            let outer = outer.shrink(self.window.dims.inner_margin as f32);
+            let outer = outer.shrink(self.w.dims.inner_margin as f32);
             self.draw.rounded_frame(outer, inner, 0.6, col);
         }
     }
 
     fn edit_box(&mut self, rect: Rect, state: InputState) {
-        let bg_col = self.cols.bg_col(state);
+        let bg_col = self.cols.edit_bg(state);
         self.draw_edit_box(rect, bg_col, self.cols.nav_region(state));
     }
 
     fn checkbox(&mut self, rect: Rect, checked: bool, state: InputState) {
-        let bg_col = self.cols.bg_col(state);
+        let bg_col = self.cols.edit_bg(state);
         let nav_col = self.cols.nav_region(state).or(Some(bg_col));
 
         let inner = self.draw_edit_box(rect, bg_col, nav_col);
@@ -346,7 +367,7 @@ where
     }
 
     fn radiobox(&mut self, rect: Rect, checked: bool, state: InputState) {
-        let bg_col = self.cols.bg_col(state);
+        let bg_col = self.cols.edit_bg(state);
         let nav_col = self.cols.nav_region(state).or(Some(bg_col));
 
         let inner = self.draw_edit_box(rect, bg_col, nav_col);
@@ -398,7 +419,7 @@ where
         }
         let thickness = outer.size().min_comp() / 2.0;
         let inner = outer.shrink(thickness);
-        let col = self.cols.button;
+        let col = self.cols.accent_soft;
         self.draw.shaded_round_frame(outer, inner, (0.0, 0.6), col);
     }
 
